AnalyticsProvider class abstract
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
logDeeplink(
{required String host, required String path, Map< String, Object> parameters = const {}}) → Future<void> -
logEvent(
{required String name, Map< String, Object> parameters = const {}}) → Future<void> -
logLogin(
{required String loginMethod}) → Future< void> -
logPurchase(
{required String transactionId, String? currency, Map< String, Object> parameters = const {}}) → Future<void> -
logSignUp(
{required String signUpMethod}) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setUserId(
{required String id}) → Future< void> -
setUserProperty(
{required String name, dynamic value}) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited