ProxyAnalyticsProvider class

Implemented types

Constructors

ProxyAnalyticsProvider(List<AnalyticsProvider> providers)

Properties

hashCode int
The hash code for this object.
no setterinherited
providers List<AnalyticsProvider>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

override
logEvent({required String name, Map<String, Object> parameters = const {}}) Future<void>
override
logLogin({required String loginMethod}) Future<void>
override
logPurchase({required String transactionId, String? currency, Map<String, Object> parameters = const {}}) Future<void>
override
logSignUp({required String signUpMethod}) Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setUserId({required String id}) Future<void>
override
setUserProperty({required String name, dynamic value}) Future<void>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited